@@ -15,7 +15,7 @@ from .query import PolymorphicQuerySet
 
 # PolymorphicQuerySet Q objects (and filter()) support these additional key words.
 # These are forbidden as field names (a descriptive exception is raised)
-POLYMORPHIC_SPECIAL_Q_KWORDS = ["instance_of", "not_instance_of"]
+POLYMORPHIC_SPECIAL_Q_KWORDS = {"instance_of", "not_instance_of"}
 
 DUMPDATA_COMMAND = os.path.join("django", "core", "management", "commands", "dumpdata.py")
 
@@ -52,69 +52,33 @@ class PolymorphicModelBase(ModelBase):
     PolymorphicQuerySet.
     """
 
-    def __new__(self, model_name, bases, attrs, **kwargs):
-        # Workaround compatibility issue with six.with_metaclass() and custom Django model metaclasses:
-        if not attrs and model_name == "NewBase":
-            return super().__new__(self, model_name, bases, attrs, **kwargs)
-
+    def __new__(cls, model_name, bases, attrs, **kwargs):
         # create new model
-        new_class = self.call_superclass_new_method(model_name, bases, attrs, **kwargs)
+        new_class = super().__new__(cls, model_name, bases, attrs, **kwargs)
 
-        # check if the model fields are all allowed
-        self.validate_model_fields(new_class)
+        if new_class._meta.base_manager_name is None:
+            # by default, use polymorphic manager as the base manager - i.e. for
+            # related fields etc. This could happen in multi-inheritance scenarios
+            # where one parent is polymorphic and the other not and the non poly parent
+            # is higher in the MRO
+            new_class._meta.base_manager_name = "objects"
 
         # validate resulting default manager
         if not new_class._meta.abstract and not new_class._meta.swapped:
-            self.validate_model_manager(new_class.objects, model_name, "objects")
+            cls.validate_model_manager(new_class.objects, model_name, "objects")
 
         # for __init__ function of this class (monkeypatching inheritance accessors)
         new_class.polymorphic_super_sub_accessors_replaced = False
 
         # determine the name of the primary key field and store it into the class variable
         # polymorphic_primary_key_name (it is needed by query.py)
-        for f in new_class._meta.fields:
-            if f.primary_key and type(f) is not models.OneToOneField:
-                new_class.polymorphic_primary_key_name = f.name
-                break
+        if new_class._meta.pk:
+            new_class.polymorphic_primary_key_name = new_class._meta.pk.name
 
         return new_class
 
     @classmethod
-    def call_superclass_new_method(self, model_name, bases, attrs, **kwargs):
-        """call __new__ method of super class and return the newly created class.
-        Also work around a limitation in Django's ModelBase."""
-        # There seems to be a general limitation in Django's app_label handling
-        # regarding abstract models (in ModelBase). See issue 1 on github - TODO: propose patch for Django
-        # We run into this problem if polymorphic.py is located in a top-level directory
-        # which is directly in the python path. To work around this we temporarily set
-        # app_label here for PolymorphicModel.
-        meta = attrs.get("Meta", None)
-        do_app_label_workaround = (
-            meta
-            and attrs["__module__"] == "polymorphic"
-            and model_name == "PolymorphicModel"
-            and getattr(meta, "app_label", None) is None
-        )
-
-        if do_app_label_workaround:
-            meta.app_label = "poly_dummy_app_label"
-        new_class = super().__new__(self, model_name, bases, attrs, **kwargs)
-        if do_app_label_workaround:
-            del meta.app_label
-        return new_class
-
-    @classmethod
-    def validate_model_fields(self, new_class):
-        "check if all fields names are allowed (i.e. not in POLYMORPHIC_SPECIAL_Q_KWORDS)"
-        for f in new_class._meta.fields:
-            if f.name in POLYMORPHIC_SPECIAL_Q_KWORDS:
-                raise AssertionError(
-                    f'PolymorphicModel: "{new_class.__name__}" - '
-                    f'field name "{f.name}" is not allowed in polymorphic models'
-                )
-
-    @classmethod
-    def validate_model_manager(self, manager, model_name, manager_name):
+    def validate_model_manager(cls, manager, model_name, manager_name):
         """check if the manager is derived from PolymorphicManager
         and its querysets from PolymorphicQuerySet - throw AssertionError if not"""
 
